pub enum ImageOs {
Linux,
Windows,
}Expand description
Operating system of the image being built.
This is distinct from the host OS — a Linux host can only build Linux images, a Windows host is required to build Windows images (via the HCS-backed backend landing in Phase L-4).
Serializes to lowercase ("linux" / "windows") for YAML/JSON configs.
Variants