is_platform_supported

Function is_platform_supported 

pub fn is_platform_supported() -> bool
Check if the current platform is supported for buildah

Buildah is primarily a Linux tool, though it can work on macOS through virtualization.