BuildTui

Struct BuildTui 

pub struct BuildTui { /* private fields */ }
Main TUI application for build progress visualization

Implementations

Source

impl BuildTui

pub fn new(event_rx: Receiver<BuildEvent>) -> Self

Create a new TUI with an event receiver

pub fn run(&mut self) -> Result<()>

Run the TUI (blocking)

This will take over the terminal, display the build progress, and return when the build completes or the user quits (q key).