build_wasm

Function build_wasm 

pub async fn build_wasm(
    context: impl AsRef<Path>,
    config: WasmBuildConfig,
) -> Result<WasmBuildResult>
Build a WASM component from source

This is the main entry point for building WASM components. It will detect the source language if not specified, run the appropriate build command, and return information about the built artifact.

Errors

Returns an error if language detection fails, the build command fails, or no output artifact is found.