pub fn get_build_command(
language: WasmLanguage,
target: WasiTarget,
release: bool,
) -> Vec<String>Expand description
Get the build command for a specific language and target
pub fn get_build_command(
language: WasmLanguage,
target: WasiTarget,
release: bool,
) -> Vec<String>Get the build command for a specific language and target