pub fn detect_runtime_with_version(
context_path: impl AsRef<Path>,
) -> Option<Runtime>Expand description
Detect runtime with version hints from project files.
This extends basic detection by attempting to read version specifications from configuration files to choose the most appropriate version.