pub enum BuildEvent {
StageStarted {
index: usize,
name: Option<String>,
base_image: String,
},
InstructionStarted {
stage: usize,
index: usize,
instruction: String,
},
Output {
line: String,
is_stderr: bool,
},
InstructionComplete {
stage: usize,
index: usize,
cached: bool,
},
StageComplete {
index: usize,
},
BuildComplete {
image_id: String,
},
BuildFailed {
error: String,
},
}Expand description
Build event for TUI updates
These events are sent from the build process to update the TUI state. The TUI processes these events asynchronously and updates the display.
Variants
StageStarted
Starting a new stage
Fields
InstructionStarted
Starting an instruction within a stage
Fields
Output
Instruction output (streaming)
Fields
InstructionComplete
Instruction completed
Fields
StageComplete
Stage completed
BuildComplete
Build complete
BuildFailed
Build failed