pub struct BuildState {
pub stages: Vec<StageState>,
pub current_stage: usize,
pub current_instruction: usize,
pub output_lines: Vec<OutputLine>,
pub scroll_offset: usize,
pub completed: bool,
pub error: Option<String>,
pub image_id: Option<String>,
}Expand description
Internal build state tracking
Fields
stages: Vec<StageState>All stages in the build
current_stage: usizeCurrent stage index
current_instruction: usizeCurrent instruction index within the current stage
output_lines: Vec<OutputLine>Output lines from the build process
scroll_offset: usizeCurrent scroll offset for output
completed: boolWhether the build has completed
error: Option<String>Error message if build failed
image_id: Option<String>Final image ID if build succeeded
Implementations
Sourceimpl BuildState
impl BuildState
Sourcepub fn total_instructions(&self) -> usize
pub fn total_instructions(&self) -> usize
Get the total number of instructions across all stages
Sourcepub fn completed_instructions(&self) -> usize
pub fn completed_instructions(&self) -> usize
Get the number of completed instructions across all stages
Sourcepub fn current_stage_display(&self) -> String
pub fn current_stage_display(&self) -> String
Get a display string for the current stage